@@ -8,7 +8,7 @@ use Getopt::Long 'GetOptions';
 use Pod::Usage 'pod2usage';
 use Proc::PID::File;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 use constant EXPORT_OK => [ qw( options pod2usage singleton ) ];
 
@@ -66,7 +66,7 @@ Util::CommandLine - Command-line interface helper utility
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Util-CommandLine.svg)](https://travis-ci.org/gryphonshafer/Util-CommandLine)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Util-CommandLine/badge.png)](https://coveralls.io/r/gryphonshafer/Util-CommandLine)
@@ -80,9 +80,8 @@ version 1.01
 
 =head1 DESCRIPTION
 
-This module conducts some automatic enviornment setup to enable command-line
-scripts that need access to the library set and either indirect (through
-the model layer) or direct database access.
+This library is command-line interface helper utility. It unifies some useful
+sub-utilities for command-line programs.
 
 =head1 EXAMPLES
 
